#
# spec file for package vulkan-validationlayers
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vulkan-validationlayers
Version:        1.2.133
Release:        1.26
Summary:        Validation layers for Vulkan
License:        Apache-2.0
Group:          Development/Tools/Other
URL:            https://github.com/KhronosGroup/Vulkan-ValidationLayers

Source:         https://github.com/KhronosGroup/Vulkan-ValidationLayers/archive/v%version.tar.gz
Source9:        %name-rpmlintrc
BuildRequires:  cmake >= 3.4
BuildRequires:  gcc-c++ >= 4.8
BuildRequires:  glslang-devel >= 8.13.3559+git20
BuildRequires:  memory-constraints
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  spirv-tools-devel >= 2020.1~git24
BuildRequires:  pkgconfig(vulkan) >= 1.1.112
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
Conflicts:      vulkan < 1.1
Obsoletes:      vulkan < 1.1

%description
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This package contains the Khronos official Vulkan validation layers.

%prep
%autosetup -n Vulkan-ValidationLayers-%version

%build
%limit_build -m 2000
%cmake -DGLSLANG_INSTALL_DIR="%_bindir"
make %{?_smp_mflags}

%install
%cmake_install
# no header files
rm -f "%buildroot/%_libdir"/*.a

%files
%license LICENSE.txt
%_libdir/libVkLayer*.so
%_datadir/vulkan/

%changelog
* Wed Feb 19 2020 alarrosa@suse.com
- Update to 1.2.133
  * corechecks: Add CmdBlitImage multiplanar format checks
  * layers: Add support for vkCmdCopyImage VUID
  * layers: Added Ycbcr support in VkImageCreateInfo
* Tue Feb 11 2020 alarrosa@suse.com
- Add conflicts and obsoletes for vulkan < 1.1 so the package replaces
  properly the vulkan package in SLE/Leap
* Mon Feb  3 2020 alarrosa@suse.com
- Update to release 1.2.132
  * Updated known-good files
  * Generated new files using `generate_source.py`
  * Updated VUIDs in validation code and tests
* Wed Jan 22 2020 jengelh@inai.de
- Update to release 1.2.131
  * layers: Add VK_KHR_buffer_device_address support
  * layers: Update validation for v1.2
  * layers: Update state tracker for v1.2
  * layers: Account for Vulkan12Features enablement
* Thu Dec 12 2019 jengelh@inai.de
- Update to release 1.1.130
  * layers: Add support for VK_KHR_separate_depth_stencil_layouts
  * layers: Add ext mem check for vkGet*MemReqs
  * layers: Fix crashes with depth/stencil resolve
  * layers: Add VK_KHR_performance_query validations
  * layers: Implement VK_KHR_timeline_semaphore validations
  * layers: Fix VK_KHR_separate_depth_stencil_layouts bugs
* Thu Nov  7 2019 jengelh@inai.de
- Update to release 1.1.127
  * layers: Update ValidateShaderStageInputOutputLimits to
    new spec rules
  * cmake: Restore creation of standard validation JSON
    file [boo#1155932]
  * layers: Add RT shader group validation
* Sat Oct 26 2019 jengelh@inai.de
- Update to release 1.1.126
  * layers: Precompute vertex attribute alignment requirement
  * layers: Add for pipeline layout compat VUs
  * layers: Store shared pointer to command pool in command buffer
  * layers: Improve large descriptor set validation filtering
  * layers: Add VK_KHR_spirv_1_4 validation
  * layers: Move event/query Updates to PostCallRecordQueueSubmit
  * layers: Validate DescriptorSet Binding data
  * layers: Add PreCallValidateCmdTraceRaysNV
* Wed Oct 16 2019 jengelh@inai.de
- Update to release 1.1.124
  * layers: Support VK_NV_dedicated_allocation_image_aliasing
  * layers: Add validation for VK_KHR_shader_subgroup_extended_types
  * layers: Add VK_NV_clip_space_w_scaling
  * layers: track vkGetPhysicalDeviceFeatures*() called state
  * gpu: Add gpu-av as a validation object
* Sun Sep 22 2019 ukbeast89@protonmail.com
- Update to new upstream release 1.1.123
  * corechecks: Add support for VK_INDEX_TYPE_UINT8_EXT
  * corechecks: Add VUs checking for indexTypeUint8
  * layers: Add VK_NV_fill_rectangle
  * layers: Re-ban ray tracing stages in render pass
  * layers: Remove QueueInfo tracking from ObjectLifetimes
  * layers: Add cgpl, ccpl, crtpl state for all intercepts
  * layers: Use persistent objects for ThreadSafety tracking
  * libVkLayer_*.so were all merged into
    libVkLayer_khronos_validation.so.
* Wed Aug 21 2019 jengelh@inai.de
- Update to new upstream release 1.1.120
  * layers: Add VK_KHR_uniform_buffer_standard_layout.
  * layers: Split record/validation of Pipeline/Shaders.
  * layers: Add accel structure tracking and validation.
  * layers: Add validation for
    VK_EXT_shader_demote_to_helper_invocation,
    VK_EXT_texel_buffer_alignment,
    VK_KHR_pipeline_executable_properties,
    VK_EXT_line_rasterization, VkGeometryNV,
    VkCommandBufferInheritanceInfo.
  * layers: Added vu checks for imageless framebuffer.
- Drop 0001-layers-Use-correct-apiversion-for-properties-check.patch
* Fri Jul 12 2019 jengelh@inai.de
- Add 0001-layers-Use-correct-apiversion-for-properties-check.patch
  [boo#1140976]
* Fri Jun 28 2019 jengelh@inai.de
- Update to new upstream release 1.1.112
  * layers: Validate VK_NV_shader_subgroup_partitioned,
    VK_NV_compute_shader_derivatives,
    VK_NV_fragment_shader_barycentric,
    VK_NV_shader_image_footprint
  * corechecks: Add some BufferImageCopy VUs
  * corechecks: Add VU checks for CUBE_COMPAT images
  * chassis: Make chassis report device extensions
  * layers: Add subgroup validation
  * layers: Validate bind image and swapchain
* Tue Jun  4 2019 jengelh@inai.de
- Update to new snapshot 1.1.107.g31
  * Fix use-after-free bug for push descriptor sets.
  * Add validation for VK_EXT_host_query_reset, QueryIndexedEXT,
    VK_KHR_shader_float_controls, VK_EXT_ycbcr_image_arrays.
  * Create khronos validation layer.
* Sun Mar 17 2019 jengelh@inai.de
- Update to new upstream release 1.1.102
  * Update various helper functions
  * Fixed some unspecified unexpected errors
  * layers: Fix null handle derefs on Destroy
* Tue Feb 19 2019 jengelh@inai.de
- Update to new upstream release 1.1.100
  * layers: Add VU check for sampled image descriptors
* Thu Jan 24 2019 jengelh@inai.de
- Update to new upstream release 1.1.97.0
  * layers: raytracing and descriptor indexing fixes
  * layers: Add VO get function to chassis
  * layers: Add bailout for CreateDevice validation
  * layers: Move parameter validation to layer chassis
  * layers: Added VK_NV_viewport_swizzle,
    VK_KHR_depth_stencil_resolve
  * layers: Support VK_EXT_memory_priority,
    VK_EXT_buffer_device_address
  * layers: Add checks for vtx_attrib_divisor extension
* Tue Dec 18 2018 jengelh@inai.de
- Update to new snapshot 1.1.96
  * Added VK_NV_fragment_coverage_to_color
  * Add validation for VK_KHR_shader_float16_int8
  * Add validation for VK_KHR_swapchain_mutable_format
* Fri Dec 14 2018 jengelh@inai.de
- Update to new snapshot 1.1.95
  * layers: Add stub functions for DebugUtils functions
  * layers: Remove unique objects standalone layer
  * layers: Add layer chassis dispatch generator
* Tue Dec  4 2018 jengelh@inai.de
- Update to new snapshot 1.1.91 (899ae294)
  * Support vulkan-headers-1.1.95
  * layers: update AHB validation to v1.1.92 definitions
* Mon Nov 12 2018 jengelh@inai.de
- Split vulkan SRPM -> vulkan-validationlayers SRPM following a
  repository split upstream.
- Update to new snapshot 1.1.91
  * Add validation for VK_KHR_draw_indirect_count.
  * Add core validation for VK_KHR_get_display_properties2.
  * Validate descriptor required component type against
    VkImageView format.
  * Implement missing VU for VUID-VkCoarseSampleOrderCustomNV-
  - sampleLocationCount.
  * Add NVX_raytracing support to validation.
* Sat Aug 25 2018 jengelh@inai.de
- Update to new snapshot 1.1.73
  * layers: Removed obsolete (and duplicate) VUIDs
  * layers: Make unique_objects ID map global
  * layers: Add VUIDs for VK_KHR_incremental_present
  * layers: Add canonical/unique ID to pipeline layout
  * layers: Add support for StorageBuffer storage class
  * loader: Add new core 1.1 entry points
  * loader: Update loader for Vulkan 1.1
  * vulkaninfo: Add core 1.1 extensions
* Fri Mar  9 2018 crrodriguez@opensuse.org
- Skip building tests that are neither packaged nor ran.
* Fri Mar  9 2018 crrodriguez@opensuse.org
- vulkan-devel has missing dependencies, this causes further
  confusion down the dependency chain, fix it by adding
  the required X and wayland components
* Wed Mar  7 2018 jengelh@inai.de
- Update to new snapshot 1.1.70
  * Support for Vulkan 1.1 (Subgroup operations)
* Wed Feb  7 2018 jengelh@inai.de
- Update to new snapshot 1.0.68
  * layers: add image layout validation to vkCmdBlitImage()
  * layers: Add VK_EXT_validation_cache implementation for shaders
  * layers: Add layer metadata for EXT_validation_cache extension
  * layers: Add descriptor limit checks to vkCreatePipelineLayout()
  * layers: Create instance & device extension lists
- Add no-git.diff
* Wed Jan 10 2018 jengelh@inai.de
- Drop ImageMagick build-time requirement
* Thu Nov 16 2017 jengelh@inai.de
- Update to new snapshot 1.0.65
  * The VK_EXT_global_priority extension extends the concept of
    device-scope queue priorities to now be a system-wide scope.
    The global/system-wide priority level takes priority over the
    per-process queue priorities.
  * New extension VK_KHR_bind_memory2: This extension allows
    vkBindBufferMemory and vkBindImageMemory to support multiple
    bindings to be performed at once while also being more
    extensible.
  * New extension VK_KHR_image_format_list: Provides a list of
    all formats that can be used with a Vulkan image when it is
    created.
  * New extension VK_KHR_maintenance2: Adds in various changes
    that were left out of Vulkan previously. These maintenance
    updates allow implementations to express clipping behavior of
    points, creating images with usage flags that may not be
    supported for the base image's format, creating uncompressed
    image views of compressed images, two new image layouts for
    depth stencil images, and other minor changes.
  * New extension VK_KHR_sampler_ycbcr_conversion: Support to
    perform specified color space conversions during texture
    sampling operations.
- Drop 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
  (included upstream)
* Sat Aug 12 2017 jengelh@inai.de
- Update to new upstream release 1.0.57.0
  * loader: Do not enumerate extensions from disabled implicit
    layers
  * layers:Handle ALL_*_BIT pipe stage barrier validation
  * LVL: Add validation check for CreateImageView
  * loader: Remove executable stack from libvulkan.so
  * layers: Fix mismatched new[] / delete
  * layers: Add new PV ranged enum validation function
  * layers: Don't do bogus transitions in invalidateCommandBuffers
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 1.0.54
  * Fix a few potential overruns
  * Configurable fallback search paths
  * Validate device features: imageCubeArray, dualSrcBlend,
    multiDrawIndirect, depthClamp, depthBounds, alphaToOne,
    samplerAnisotropy.
  * Add compressed texture query utils
  * Add feature checks for textureCompressionETC2,
    textureCompressionASTC_LDR, textureCompressionBC,
    sparseBinding device, sparseResidencyBuffer,
    sparseResidencyAliased, depthBiasClamp.
  * Remove deprecated KHX extension from OT/PV
  * Support CapabilityGeometryShaderPassThroughNV and
    CapabilitySampleMaskOverrideCoverage.
  * Support the viewport_array2, shader_subgroup_ballot and
    shader_subgroup_vote ext shader caps.
  * Change size of X8_D24_UNORM_PACK32 and D32_SFLOAT_S8_UINT
- Add 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
* Mon Feb 20 2017 jengelh@inai.de
- Update to new upstream release 1.0.41
  * layers: Move image struct into cv_types header
  * layers: Move CreateImage validation into core_val
  * layers: Move DestroyImage code into buffer module
  * layers: Move CreateRenderPass format check to PV
  * layers: Rename misleading renderpass structure var
  * layers:Move gfx pipe check to create time
  * layers: Move image validation support to buffer_val
  * layers: Add enable for NV_GLSL_SHADER extension
- Add baselibs.conf [needed by libgtk-4-0]
* Mon Jan 30 2017 jengelh@inai.de
- Update to new upstream release 1.0.39.1
  * layers: Add tracking for VK_KHR_display extension in PV
  * layers: Add null checks to RetireWorkOnQueue
  * vulkaninfo: fix segfault when DISPLAY is not set
  * layers: Complete support for VK_KHR_Display ext
* Mon Oct 31 2016 jengelh@inai.de
- Update to 1.0.32.g28
  * vkjson: Rename VkJsonAllProperties to VkJsonDevice
  * loader: Fix json output of escape chars
  * loader: Fix segfault in vulkaninfo
  * Add vulkan C++ header
- Remove 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch
  (upstreamed).
* Mon Jun 13 2016 jengelh@inai.de
- Update to new snapshot 1.0.3.g5493
  * Added helpers: getSwapchainNode(), getSwapchainFromImage(),
  getImageNode(), getImageViewData(), getSamplerNode(),
  getBufferViewInfo(), getBufferNode().
- Resolve build failure stemming from new glslang version
- Add 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch.
  These were in a prior tarball made from a Fedora git,
  but we since switched to the upstream git.
* Wed Feb 17 2016 jengelh@inai.de
- Initial package (version 1.0.3.g19) for build.opensuse.org
